pub struct MemoryGuardBuilder { /* private fields */ }Expand description
Builder for MemoryGuard.
let device = Arc::new(GpuDevice::new(0).unwrap());
let guard = MemoryGuardBuilder::new(device)
.budget_bytes(16 * 1024 * 1024 * 1024)
.reserve_bytes(16 * 1024 * 1024 * 1024)
.oom_policy(OomPolicy::RetryAfterFree)
.build()
.unwrap();Implementations
Sourceimpl MemoryGuardBuilder
impl MemoryGuardBuilder
Sourcepub fn budget_bytes(self, bytes: usize) -> Self
pub fn budget_bytes(self, bytes: usize) -> Self
Set the hard memory budget in bytes. 0 means unlimited.
Sourcepub fn reserve_bytes(self, bytes: usize) -> Self
pub fn reserve_bytes(self, bytes: usize) -> Self
Pre-allocate bytes of VRAM as a reservation sentinel.
Other processes cannot use this memory while the guard is alive.
Sourcepub fn oom_policy(self, policy: OomPolicy) -> Self
pub fn oom_policy(self, policy: OomPolicy) -> Self
Set the OOM recovery policy.
Sourcepub fn build(self) -> GpuResult<MemoryGuard>
pub fn build(self) -> GpuResult<MemoryGuard>
Build the MemoryGuard.
If reserve_bytes was set, this will attempt to allocate the
sentinel buffer. Failure to allocate is returned as an error.