StreamGuard

Struct StreamGuard 

pub struct StreamGuard { /* private fields */ }
RAII guard that sets the thread-local current stream on construction and restores the previous stream (or clears it) on drop.

Example

use ferrotorch_gpu::stream::{StreamGuard, StreamPool};

let stream = StreamPool::get_stream(&ctx, 0)?;
{
    let _guard = StreamGuard::new(0, stream);
    // All operations on device 0 in this scope use `stream`.
    // ...
}
// Previous stream (or default) is restored here.

Implementations

Source

impl StreamGuard

pub fn new(device: usize, stream: Arc<CudaStream>) -> Self

Set stream as the current stream for device on this thread.

The previous current stream (if any) is saved and will be restored when this guard is dropped.