GpuError

Enum GpuError 

#[non_exhaustive]
pub enum GpuError { Driver(DriverError), InvalidDevice { ordinal: usize, count: usize, }, DeviceMismatch { expected: usize, got: usize, }, OutOfMemory { requested_bytes: usize, free_bytes: usize, }, BudgetExceeded { requested_bytes: usize, budget_bytes: usize, used_bytes: usize, }, LengthMismatch { a: usize, b: usize, }, ShapeMismatch { op: &'static str, expected: Vec<usize>, got: Vec<usize>, }, Blas(CublasError), PtxCompileFailed { kernel: &'static str, }, InvalidState { message: String, }, }
Errors produced by GPU operations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Driver(DriverError)

CUDA driver error forwarded from cudarc.



InvalidDevice

Device ordinal is out of range.

Fields

ordinal: usize
count: usize


DeviceMismatch

Tried to operate on buffers from different devices.

Fields

expected: usize
got: usize


OutOfMemory

GPU out of memory. Contains the requested size and the free bytes at the time of the failed allocation.

Fields

requested_bytes: usize
free_bytes: usize


BudgetExceeded

Allocation rejected because it would exceed the user-configured memory budget (see crate::memory_guard::MemoryGuard::set_budget).

Fields

requested_bytes: usize
budget_bytes: usize
used_bytes: usize


LengthMismatch

Binary op received buffers with different lengths.

Fields



ShapeMismatch

Matrix multiplication shape mismatch (inner dimensions differ).

Fields

op: &'static str
expected: Vec<usize>
got: Vec<usize>


Blas(CublasError)

cuBLAS error forwarded from cudarc.



PtxCompileFailed

PTX kernel compilation failed (e.g. unsupported GPU architecture).

Fields

kernel: &'static str


InvalidState

An operation was attempted in an invalid state (e.g., capture on a sealed pool, or cuSOLVER reported a negative info value).

Fields

message: String