pub struct CapturedGraph { /* private fields */ }Expand description
A captured and instantiated CUDA graph that can be replayed with
launch.
Created via begin_capture + GPU ops + end_capture.
The graph holds references to all device memory used during capture.
Those buffers must remain allocated for the lifetime of the graph.
Implementations
Sourceimpl CapturedGraph
impl CapturedGraph
Sourcepub fn launch(&self) -> GpuResult<()>
pub fn launch(&self) -> GpuResult<()>
Replay all operations captured in this graph.
Before calling this, update any DeviceScalar values and perform
any pre-launch memcpys (e.g., position embeddings). All updates must
be on the same stream the graph was captured on.